# sysnet-taxonomy
Toto je API pro taxonomii CITES

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.1
- Package version: 1.0.1.001
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install taxonomy
```

Then import the package:
```python
import taxonomy 
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import taxonomy
from taxonomy.rest import ApiException
from pprint import pprint

# Configure API key authorization: apiKey
configuration = taxonomy.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = taxonomy.AdminsApi(taxonomy.ApiClient(configuration))
body = taxonomy.TaxonType() # TaxonType | Taxon item to add or update

try:
    # přidá nový taxon
    api_response = api_instance.add_taxon(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdminsApi->add_taxon: %s\n" % e)

# Configure API key authorization: apiKey
configuration = taxonomy.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = taxonomy.AdminsApi(taxonomy.ApiClient(configuration))
identifier = 'identifier_example' # str | PID nebo celý vědecký název taxonu

try:
    # odstraní existující taxon
    api_instance.delete_taxon(identifier)
except ApiException as e:
    print("Exception when calling AdminsApi->delete_taxon: %s\n" % e)

# Configure API key authorization: apiKey
configuration = taxonomy.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = taxonomy.AdminsApi(taxonomy.ApiClient(configuration))
body = taxonomy.TaxonType() # TaxonType | Taxon item to add or update
identifier = 'identifier_example' # str | PID nebo celý vědecký název taxonu

try:
    # upraví existující taxon
    api_instance.put_taxon(body, identifier)
except ApiException as e:
    print("Exception when calling AdminsApi->put_taxon: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://service.sysnet.cz/taxonomy/1.0.1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminsApi* | [**add_taxon**](docs/AdminsApi.md#add_taxon) | **POST** /taxon | přidá nový taxon
*AdminsApi* | [**delete_taxon**](docs/AdminsApi.md#delete_taxon) | **DELETE** /taxon/{identifier} | odstraní existující taxon
*AdminsApi* | [**put_taxon**](docs/AdminsApi.md#put_taxon) | **PUT** /taxon/{identifier} | upraví existující taxon
*DevelopersApi* | [**info_api**](docs/DevelopersApi.md#info_api) | **GET** /info | vrací servisní informace
*DevelopersApi* | [**info_api_head**](docs/DevelopersApi.md#info_api_head) | **HEAD** /info | vrací informaci o dostupnosti služby
*PublicApi* | [**get_taxon**](docs/PublicApi.md#get_taxon) | **GET** /taxon/{identifier} | Vrátí konkrétní taxon
*PublicApi* | [**search_taxons**](docs/PublicApi.md#search_taxons) | **GET** /taxon | Vrátí seznam taxonů pro pohled nebo výběr

## Documentation For Models

 - [AdditionalType](docs/AdditionalType.md)
 - [ErrorModel](docs/ErrorModel.md)
 - [HybridType](docs/HybridType.md)
 - [TaxonEntryListType](docs/TaxonEntryListType.md)
 - [TaxonEntryType](docs/TaxonEntryType.md)
 - [TaxonType](docs/TaxonType.md)

## Documentation For Authorization


## apiKey

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

rjaeger@sysnet.cz
